
# This file is autogenerated from Microsoft documentation. Don't edit!
package Mail::Exchange::PropertyTypes;
use Exporter;
use vars qw (@ISA @EXPORTER);
@ISA=qw(Exporter);
# @EXPORT at the bottom because this file is autogenerated

my %PropertyTypes=(

	0x0002 => "PtypInteger16",
	0x0003 => "PtypInteger32",
	0x0004 => "PtypInteger32",
	0x0005 => "PtypFloating64",
	0x000B => "PtypBoolean",
	0x000D => "PtypObject",
	0x0014 => "PtypInteger64",
	0x001E => "PtypString8",
	0x001F => "PtypString",
	0x0040 => "PtypTime",
	0x0048 => "PtypGuid",
	0x00FB => "PtypServerId",
	0x00FD => "PtypRestriction",
	0x00FE => "PtypRuleAction",
	0x0102 => "PtypBinary",
	0x1003 => "PtypMultipleInteger32",
	0x101F => "PtypMultipleString",
	0x1040 => "PtypMultipleTime",
	0x1102 => "PtypMultipleBinary",
	PtypBinary => 0x0102,
	PtypBoolean => 0x000B,
	PtypEmbeddedTable => 0x000D,
	PtypFloating64 => 0x0005,
	PtypGuid => 0x0048,
	PtypInteger16 => 0x0002,
	PtypInteger32 => 0x0003,
	PtypInteger64 => 0x0014,
	PtypMultipleBinary => 0x1102,
	PtypMultipleInteger32 => 0x1003,
	PtypMultipleString => 0x101F,
	PtypMultipleTime => 0x1040,
	PtypObject => 0x000D,
	PtypRestriction => 0x00FD,
	PtypRuleAction => 0x00FE,
	PtypServerId => 0x00FB,
	PtypString => 0x001F,
	PtypString8 => 0x001E,
	PtypTime => 0x0040,
);
sub PtypBinary { return 0x0102;}
sub PtypBoolean { return 0x000B;}
sub PtypEmbeddedTable { return 0x000D;}
sub PtypFloating64 { return 0x0005;}
sub PtypGuid { return 0x0048;}
sub PtypInteger16 { return 0x0002;}
sub PtypInteger32 { return 0x0003;}
sub PtypInteger64 { return 0x0014;}
sub PtypMultipleBinary { return 0x1102;}
sub PtypMultipleInteger32 { return 0x1003;}
sub PtypMultipleString { return 0x101F;}
sub PtypMultipleTime { return 0x1040;}
sub PtypObject { return 0x000D;}
sub PtypRestriction { return 0x00FD;}
sub PtypRuleAction { return 0x00FE;}
sub PtypServerId { return 0x00FB;}
sub PtypString { return 0x001F;}
sub PtypString8 { return 0x001E;}
sub PtypTime { return 0x0040;}

@EXPORT=qw(%PropertyTypes PtypBinary PtypBoolean PtypEmbeddedTable PtypFloating64 PtypGuid PtypInteger16 PtypInteger32 PtypInteger64 PtypMultipleBinary PtypMultipleInteger32 PtypMultipleString PtypMultipleTime PtypObject PtypRestriction PtypRuleAction PtypServerId PtypString PtypString8 PtypTime);

1;
