
# This file is autogenerated from Microsoft documentation. Don't edit!
# LIDs are stored as (lid<<16|type), so when using these, remember to
# shift the LID right by 16 bits to get the "real" lid.
package Mail::Exchange::PidLidIDs;
use Exporter;
use vars qw(@ISA @EXPORTER);
@ISA=qw(Exporter);
# @EXPORT at the bottom because this file is autogenerated

sub PidLidPostRssItemLink { return 0x8901001F; }
sub PidLidDistributionListOneOffMembers { return 0x80541102; }
sub PidLidTaskLastDelegate { return 0x8125001F; }
sub PidLidOptionalAttendees { return 0x0007001F; }
sub PidLidNoteColor { return 0x8B000003; }
sub PidLidIntendedBusyStatus { return 0x82240003; }
sub PidLidAllAttendeesString { return 0x8238001F; }
sub PidLidSharingStatus { return 0x8A000003; }
sub PidLidFlagString { return 0x85C00003; }
sub PidLidAppointmentAuxiliaryFlags { return 0x82070003; }
sub PidLidSideEffects { return 0x85100003; }
sub PidLidNoteX { return 0x8B040003; }
sub PidLidSharingRemoteComment { return 0x8A2F001F; }
sub PidLidNonSendableTo { return 0x8536001F; }
sub PidLidConversationActionVersion { return 0x85CB0003; }
sub PidLidTaskDueDate { return 0x81050040; }
sub PidLidTaskHistory { return 0x811A0003; }
sub PidLidSharingAnonymity { return 0x8A190003; }
sub PidLidSharingTimeToLive { return 0x8A2C0003; }
sub PidLidDayInterval { return 0x00110002; }
sub PidLidNonSendBccTrackStatus { return 0x85451003; }
sub PidLidOldWhenStartWhole { return 0x00290040; }
sub PidLidSharingConfigurationUrl { return 0x8A24001F; }
sub PidLidFax3OriginalEntryId { return 0x80D50102; }
sub PidLidSharingPermissions { return 0x8A1B0003; }
sub PidLidDistributionListStream { return 0x80640102; }
sub PidLidBilling { return 0x8535001F; }
sub PidLidClipEnd { return 0x82360040; }
sub PidLidSharingRemoteType { return 0x8A1D001F; }
sub PidLidSharingResponseTime { return 0x8A280040; }
sub PidLidWorkAddress { return 0x801B001F; }
sub PidLidPostalAddressId { return 0x80220003; }
sub PidLidLogDocumentSaved { return 0x870F000B; }
sub PidLidDayOfMonth { return 0x10000003; }
sub PidLidAppointmentEndTime { return 0x82100040; }
sub PidLidClassificationKeep { return 0x85BA000B; }
sub PidLidPostRssChannelLink { return 0x8900001F; }
sub PidLidOwnerName { return 0x822E001F; }
sub PidLidRemoteStatus { return 0x85110003; }
sub PidLidSharingDataRangeEnd { return 0x8A450040; }
sub PidLidSharingProviderExtension { return 0x8A0B001F; }
sub PidLidServerProcessingActions { return 0x85CD0003; }
sub PidLidSharingRemoteStoreUid { return 0x8A48001F; }
sub PidLidTaskAccepted { return 0x8108000B; }
sub PidLidAgingDontAgeMe { return 0x850E000B; }
sub PidLidAppointmentUpdateTime { return 0x82260040; }
sub PidLidContactUserField2 { return 0x8050001F; }
sub PidLidMonthOfYearMask { return 0x00170003; }
sub PidLidConferencingCheck { return 0x8240000B; }
sub PidLidReminderSet { return 0x8503000B; }
sub PidLidBusinessCardDisplayDefinition { return 0x80400102; }
sub PidLidSharingStart { return 0x8A250040; }
sub PidLidAppointmentRecur { return 0x82160102; }
sub PidLidRecurrenceType { return 0x82310003; }
sub PidLidTaskStatusOnComplete { return 0x8119000B; }
sub PidLidSharingSyncFlags { return 0x8A600003; }
sub PidLidToDoTitle { return 0x85A4001F; }
sub PidLidSharingRemoteUser { return 0x8A0C001F; }
sub PidLidVerbResponse { return 0x8524001F; }
sub PidLidDelegateMail { return 0x0009000B; }
sub PidLidTaskGlobalId { return 0x85190102; }
sub PidLidAppointmentReplyTime { return 0x82200040; }
sub PidLidSharingDetail { return 0x8A2B0003; }
sub PidLidContactLinkLinkRejectHistory { return 0x80E51102; }
sub PidLidClassificationGuid { return 0x85B8001F; }
sub PidLidAppointmentProposalNumber { return 0x82590003; }
sub PidLidLogType { return 0x8700001F; }
sub PidLidWhere { return 0x0002001F; }
sub PidLidAppointmentEndWhole { return 0x820E0040; }
sub PidLidContactUserField1 { return 0x804F001F; }
sub PidLidAutoProcessState { return 0x851A0003; }
sub PidLidConversationProcessed { return 0x85C90003; }
sub PidLidAppointmentStartTime { return 0x820F0040; }
sub PidLidTaskDeadOccurrence { return 0x8109000B; }
sub PidLidEmail3AddressType { return 0x80A2001F; }
sub PidLidEmail3DisplayName { return 0x80A0001F; }
sub PidLidTaskOrdinal { return 0x81230003; }
sub PidLidPostRssSubscription { return 0x8906001F; }
sub PidLidSharingLocalType { return 0x8A14001F; }
sub PidLidAppointmentStateFlags { return 0x82170003; }
sub PidLidResponseStatus { return 0x82180003; }
sub PidLidWorkAddressPostOfficeBox { return 0x804A001F; }
sub PidLidToDoSubOrdinal { return 0x85A1001F; }
sub PidLidPostRssItemXml { return 0x8905001F; }
sub PidLidEmail2EmailAddress { return 0x8093001F; }
sub PidLidTaskMode { return 0x85180003; }
sub PidLidWorkAddressCity { return 0x8046001F; }
sub PidLidSharingLastSyncTime { return 0x8A1F0040; }
sub PidLidEmail2DisplayName { return 0x8090001F; }
sub PidLidHtml { return 0x802B001F; }
sub PidLidIsSilent { return 0x0004000B; }
sub PidLidTaskOwner { return 0x811F001F; }
sub PidLidPostRssItemHash { return 0x89020003; }
sub PidLidRecurrenceDuration { return 0x100D0003; }
sub PidLidOldWhenEndWhole { return 0x002A0040; }
sub PidLidTaskVersion { return 0x81120003; }
sub PidLidSharingResponseType { return 0x8A270003; }
sub PidLidSharingLocalName { return 0x8A0F001F; }
sub PidLidTimeZoneStruct { return 0x82330102; }
sub PidLidLinkedTaskItems { return 0x820C1102; }
sub PidLidSharingReciprocation { return 0x8A1A0003; }
sub PidLidHomeAddressCountryCode { return 0x80DA001F; }
sub PidLidCollaborateDoc { return 0x8247001F; }
sub PidLidSharingLocalUid { return 0x8A10001F; }
sub PidLidReminderTime { return 0x85020040; }
sub PidLidTimeZoneDescription { return 0x8234001F; }
sub PidLidSharingRemotePath { return 0x8A04001F; }
sub PidLidNoteY { return 0x8B050003; }
sub PidLidIsRecurring { return 0x0005000B; }
sub PidLidFOthersAppointment { return 0x822F000B; }
sub PidLidSharingWorkingHoursEnd { return 0x8A410040; }
sub PidLidClassificationDescription { return 0x85B7001F; }
sub PidLidFax3AddressType { return 0x80D2001F; }
sub PidLidExceptionReplaceTime { return 0x82280040; }
sub PidLidReminderPlaySound { return 0x851E000B; }
sub PidLidAutoLog { return 0x8025000B; }
sub PidLidSingleBodyICal { return 0x827B000B; }
sub PidLidEmail3EmailAddress { return 0x80A3001F; }
sub PidLidReferenceEntryId { return 0x85BD0102; }
sub PidLidWorkAddressPostalCode { return 0x8048001F; }
sub PidLidSharingParentBindingEntryId { return 0x8A5C0102; }
sub PidLidSmartNoAttach { return 0x8514000B; }
sub PidLidEmail3OriginalDisplayName { return 0x80A4001F; }
sub PidLidAddressBookProviderEmailList { return 0x80281003; }
sub PidLidLogDocumentPosted { return 0x8711000B; }
sub PidLidNoEndDateFlag { return 0x100B000B; }
sub PidLidRequiredAttendees { return 0x0006001F; }
sub PidLidFax1OriginalDisplayName { return 0x80B4001F; }
sub PidLidTaskRole { return 0x8127001F; }
sub PidLidAppointmentReplyName { return 0x8230001F; }
sub PidLidYomiCompanyName { return 0x802E001F; }
sub PidLidTaskFFixOffline { return 0x812C000B; }
sub PidLidICalendarDayOfWeekMask { return 0x10010003; }
sub PidLidInstantMessagingAddress { return 0x8062001F; }
sub PidLidBirthdayEventEntryId { return 0x804D0102; }
sub PidLidTaskComplete { return 0x811C000B; }
sub PidLidOtherAddress { return 0x801C001F; }
sub PidLidTrustRecipientHighlights { return 0x823E000B; }
sub PidLidLogDocumentPrinted { return 0x870E000B; }
sub PidLidSharingBindingEntryId { return 0x8A2D0102; }
sub PidLidClassified { return 0x85B5000B; }
sub PidLidOriginalStoreEntryId { return 0x82370102; }
sub PidLidUseTnef { return 0x8582000B; }
sub PidLidInternetAccountName { return 0x8580001F; }
sub PidLidSharingRemoteLastModificationTime { return 0x8A220040; }
sub PidLidTeamTask { return 0x8103000B; }
sub PidLidFax1OriginalEntryId { return 0x80B50102; }
sub PidLidConversationActionMoveStoreEid { return 0x85C70102; }
sub PidLidTaskFCreator { return 0x811E000B; }
sub PidLidSharingStop { return 0x8A260040; }
sub PidLidEmail1DisplayName { return 0x8080001F; }
sub PidLidFax1EmailAddress { return 0x80B3001F; }
sub PidLidConferencingType { return 0x82410003; }
sub PidLidMonthOfYear { return 0x10060003; }
sub PidLidSharingParticipants { return 0x8A1E001F; }
sub PidLidSharingIndexEntryId { return 0x8A2E0102; }
sub PidLidContactLinkSMTPAddressCache { return 0x80E3101F; }
sub PidLidTaskActualEffort { return 0x81100003; }
sub PidLidServerProcessed { return 0x85CC000B; }
sub PidLidAllowExternalCheck { return 0x8246000B; }
sub PidLidCompanies { return 0x8539101F; }
sub PidLidFax2OriginalEntryId { return 0x80C50102; }
sub PidLidClassification { return 0x85B6001F; }
sub PidLidFreeBusyLocation { return 0x80D8001F; }
sub PidLidForwardNotificationRecipients { return 0x82610102; }
sub PidLidSharingRangeEnd { return 0x8A470003; }
sub PidLidSharingInstanceGuid { return 0x8A1C0102; }
sub PidLidStartRecurrenceDate { return 0x000D0003; }
sub PidLidAppointmentProposedStartWhole { return 0x82500040; }
sub PidLidPercentComplete { return 0x81020005; }
sub PidLidEmail1OriginalEntryId { return 0x80850102; }
sub PidLidDepartment { return 0x8010001F; }
sub PidLidDistributionListMembers { return 0x80551102; }
sub PidLidSharingLastAutoSyncTime { return 0x8A550040; }
sub PidLidValidFlagStringProof { return 0x85BF0040; }
sub PidLidLocation { return 0x8208001F; }
sub PidLidSharingFlags { return 0x8A0A0003; }
sub PidLidSharingLocalPath { return 0x8A0E001F; }
sub PidLidInfoPathFormName { return 0x85B1001F; }
sub PidLidReferredBy { return 0x800E001F; }
sub PidLidSharingInitiatorSmtp { return 0x8A08001F; }
sub PidLidHasPicture { return 0x8015000B; }
sub PidLidSharingRemoteUid { return 0x8A06001F; }
sub PidLidToAttendeesString { return 0x823B001F; }
sub PidLidEmail2AddressType { return 0x8092001F; }
sub PidLidContactItemData { return 0x80071003; }
sub PidLidWorkAddressStreet { return 0x8045001F; }
sub PidLidInboundICalStream { return 0x827A0102; }
sub PidLidPendingStateForTeamMailboxDocument { return 0x00000004; }
sub PidLidDistributionListName { return 0x8053001F; }
sub PidLidTaskAcceptanceState { return 0x812A0003; }
sub PidLidSharingRangeStart { return 0x8A460003; }
sub PidLidToDoOrdinalDate { return 0x85A00040; }
sub PidLidFExceptionalAttendees { return 0x822B000B; }
sub PidLidTaskDateCompleted { return 0x810F0040; }
sub PidLidWeekInterval { return 0x00120002; }
sub PidLidTaskStartDate { return 0x81040040; }
sub PidLidTaskCustomFlags { return 0x81390003; }
sub PidLidSharingWorkingHoursStart { return 0x8A400040; }
sub PidLidNonSendToTrackStatus { return 0x85431003; }
sub PidLidSharingRemoteVersion { return 0x8A5B001F; }
sub PidLidContactLinkEntry { return 0x85850102; }
sub PidLidHomeAddress { return 0x801A001F; }
sub PidLidClientIntent { return 0x00150003; }
sub PidLidTaskOwnership { return 0x81290003; }
sub PidLidSharingLocalLastModificationTime { return 0x8A230040; }
sub PidLidNonSendableCc { return 0x8537001F; }
sub PidLidFax3EmailAddress { return 0x80D3001F; }
sub PidLidNonSendCcTrackStatus { return 0x85441003; }
sub PidLidSharingRoamLog { return 0x8A4E0003; }
sub PidLidMeetingType { return 0x00260003; }
sub PidLidRecurrencePattern { return 0x8232001F; }
sub PidLidCurrentVersionName { return 0x8554001F; }
sub PidLidAnniversaryEventEntryId { return 0x804E0102; }
sub PidLidForwardInstance { return 0x820A000B; }
sub PidLidSharingProviderGuid { return 0x8A010102; }
sub PidLidFax2EmailAddress { return 0x80C3001F; }
sub PidLidNetShowUrl { return 0x8248001F; }
sub PidLidSharingOriginalMessageEntryId { return 0x8A290102; }
sub PidLidReminderDelta { return 0x85010003; }
sub PidLidOccurrences { return 0x10050003; }
sub PidLidFileUnder { return 0x8005001F; }
sub PidLidMeetingWorkspaceUrl { return 0x8209001F; }
sub PidLidAddressCountryCode { return 0x80DD001F; }
sub PidLidTimeZone { return 0x000C0003; }
sub PidLidSharingRemoteCrc { return 0x8A4C0003; }
sub PidLidAppointmentStartWhole { return 0x820D0040; }
sub PidLidAppointmentDuration { return 0x82130003; }
sub PidLidNoteWidth { return 0x8B020003; }
sub PidLidAppointmentTimeZoneDefinitionRecur { return 0x82600102; }
sub PidLidAppointmentTimeZoneDefinitionEndDisplay { return 0x825F0102; }
sub PidLidSharingProviderUrl { return 0x8A03001F; }
sub PidLidEmail1AddressType { return 0x8082001F; }
sub PidLidConversationActionLastAppliedTime { return 0x85CA0040; }
sub PidLidNonSendableBcc { return 0x8538001F; }
sub PidLidContactUserField4 { return 0x8052001F; }
sub PidLidYomiLastName { return 0x802D001F; }
sub PidLidWorkAddressCountry { return 0x8049001F; }
sub PidLidSharingCapabilities { return 0x8A170003; }
sub PidLidBirthdayLocal { return 0x80DE0040; }
sub PidLidConversationActionMoveFolderEid { return 0x85C60102; }
sub PidLidSharingSyncInterval { return 0x8A2A0003; }
sub PidLidTaskNoCompute { return 0x8124000B; }
sub PidLidTaskLastUser { return 0x8122001F; }
sub PidLidPostRssItemGuid { return 0x8903001F; }
sub PidLidFax2OriginalDisplayName { return 0x80C4001F; }
sub PidLidCalendarType { return 0x001C0003; }
sub PidLidSharingRemoteName { return 0x8A05001F; }
sub PidLidGlobalObjectId { return 0x00030102; }
sub PidLidEndRecurrenceTime { return 0x00100003; }
sub PidLidSharingRemoteByteSize { return 0x8A4B0003; }
sub PidLidSharingDataRangeStart { return 0x8A440040; }
sub PidLidYomiFirstName { return 0x802C001F; }
sub PidLidFlagRequest { return 0x8530001F; }
sub PidLidRecurring { return 0x8223000B; }
sub PidLidFax2AddressType { return 0x80C2001F; }
sub PidLidSharingWorkingHoursDays { return 0x8A420003; }
sub PidLidContactLinkSearchKey { return 0x85840102; }
sub PidLidMonthInterval { return 0x00130002; }
sub PidLidSharingBrowseUrl { return 0x8A51001F; }
sub PidLidAppointmentUnsendableRecipients { return 0x825D0102; }
sub PidLidContactLinkGlobalAddressListLinkState { return 0x80E60003; }
sub PidLidOtherAddressCountryCode { return 0x80DC001F; }
sub PidLidWeddingAnniversaryLocal { return 0x80DF0040; }
sub PidLidChangeHighlight { return 0x82040003; }
sub PidLidOldRecurrenceType { return 0x00180002; }
sub PidLidCategories { return 0x9000101F; }
sub PidLidFileUnderId { return 0x80060003; }
sub PidLidAppointmentProposedEndWhole { return 0x82510040; }
sub PidLidCommonEnd { return 0x85170040; }
sub PidLidAppointmentColor { return 0x82140003; }
sub PidLidPrivate { return 0x8506000B; }
sub PidLidAppointmentSequence { return 0x82010003; }
sub PidLidSharingFolderEntryId { return 0x8A150102; }
sub PidLidReminderOverride { return 0x851C000B; }
sub PidLidOrganizerAlias { return 0x8243001F; }
sub PidLidSharingLocalStoreUid { return 0x8A49001F; }
sub PidLidSharingLocalComment { return 0x8A4D001F; }
sub PidLidLogTypeDesc { return 0x8712001F; }
sub PidLidConversationActionMaxDeliveryTime { return 0x85C80040; }
sub PidLidReminderTimeTime { return 0x85040040; }
sub PidLidFax3OriginalDisplayName { return 0x80D4001F; }
sub PidLidAppointmentTimeZoneDefinitionStartDisplay { return 0x825E0102; }
sub PidLidAppointmentSequenceTime { return 0x82020040; }
sub PidLidReminderFileParameter { return 0x851F001F; }
sub PidLidCommonStart { return 0x85160040; }
sub PidLidTaskEstimatedEffort { return 0x81110003; }
sub PidLidTaskMultipleRecipients { return 0x81200003; }
sub PidLidReminderSignalTime { return 0x85600040; }
sub PidLidAppointmentMessageClass { return 0x0024001F; }
sub PidLidYearInterval { return 0x00140002; }
sub PidLidFileUnderList { return 0x80261003; }
sub PidLidSharingRemoteMessageCount { return 0x8A4F0003; }
sub PidLidContactUserField3 { return 0x8051001F; }
sub PidLidAutoStartCheck { return 0x8244000B; }
sub PidLidContactLinkName { return 0x8586001F; }
sub PidLidAppointmentSubType { return 0x8215000B; }
sub PidLidBusinessCardCardPicture { return 0x80410102; }
sub PidLidIsException { return 0x000A000B; }
sub PidLidSharingTimeToLiveAuto { return 0x8A560003; }
sub PidLidResourceAttendees { return 0x0008001F; }
sub PidLidSharingProviderName { return 0x8A02001F; }
sub PidLidSpamOriginalFolder { return 0x859C0102; }
sub PidLidAppointmentProposedDuration { return 0x82560003; }
sub PidLidVerbStream { return 0x85200102; }
sub PidLidLogDuration { return 0x87070003; }
sub PidLidAppointmentEndDate { return 0x82110040; }
sub PidLidInternetAccountStamp { return 0x8581001F; }
sub PidLidEmail1OriginalDisplayName { return 0x8084001F; }
sub PidLidEmail2OriginalDisplayName { return 0x8094001F; }
sub PidLidAppointmentNotAllowPropose { return 0x825A000B; }
sub PidLidOwnerCriticalChange { return 0x001A0040; }
sub PidLidAppointmentLastSequence { return 0x82030003; }
sub PidLidTaskAssigner { return 0x8121001F; }
sub PidLidSharingFlavor { return 0x8A180003; }
sub PidLidSharingFilter { return 0x8A130102; }
sub PidLidBusyStatus { return 0x82050003; }
sub PidLidSharingInitiatorName { return 0x8A07001F; }
sub PidLidWorkAddressState { return 0x8047001F; }
sub PidLidSharingExtensionXml { return 0x8A21001F; }
sub PidLidAddressBookProviderArrayType { return 0x80290003; }
sub PidLidCurrentVersion { return 0x85520003; }
sub PidLidEmail2OriginalEntryId { return 0x80950102; }
sub PidLidTaskRecurrence { return 0x81160102; }
sub PidLidOldLocation { return 0x0028001F; }
sub PidLidWorkAddressCountryCode { return 0x80DB001F; }
sub PidLidFax1AddressType { return 0x80B2001F; }
sub PidLidLogFlags { return 0x870C0003; }
sub PidLidAppointmentStartDate { return 0x82120040; }
sub PidLidPromptSendUpdate { return 0x8045000B; }
sub PidLidOnlinePassword { return 0x8249001F; }
sub PidLidReminderType { return 0x851D0003; }
sub PidLidContactLinkedGlobalAddressListEntryId { return 0x80E20102; }
sub PidLidContacts { return 0x853A101F; }
sub PidLidContactLinkGlobalAddressListLinkId { return 0x80E80048; }
sub PidLidTaskResetReminder { return 0x8107000B; }
sub PidLidEmail3OriginalEntryId { return 0x80A50102; }
sub PidLidTaskUpdates { return 0x811B000B; }
sub PidLidEndRecurrenceDate { return 0x000F0003; }
sub PidLidNoteHeight { return 0x8B030003; }
sub PidLidAutoFillLocation { return 0x823A000B; }
sub PidLidTaskState { return 0x81130003; }
sub PidLidIsContactLinked { return 0x80E0000B; }
sub PidLidLogStart { return 0x87060040; }
sub PidLidFExceptionalBody { return 0x8206000B; }
sub PidLidLogEnd { return 0x87080040; }
sub PidLidSharingWorkingHoursTimeZone { return 0x8A430000; }
sub PidLidTaskStatus { return 0x81010003; }
sub PidLidClipStart { return 0x82350040; }
sub PidLidLogDocumentRouted { return 0x8710000B; }
sub PidLidDirectory { return 0x8242001F; }
sub PidLidSharingInitiatorEntryId { return 0x8A090102; }
sub PidLidTaskFRecurring { return 0x8126000B; }
sub PidLidContactCharacterSet { return 0x80230003; }
sub PidLidFInvited { return 0x8229000B; }
sub PidLidPostRssChannel { return 0x8904001F; }
sub PidLidCcAttendeesString { return 0x823C001F; }
sub PidLidReminderTimeDate { return 0x85050040; }
sub PidLidTaskLastUpdate { return 0x81150040; }
sub PidLidEmail1EmailAddress { return 0x8083001F; }
sub PidLidSharingRemotePass { return 0x8A0D001F; }
sub PidLidStartRecurrenceTime { return 0x000E0003; }
sub PidLidCleanGlobalObjectId { return 0x00230102; }
sub PidLidTaskAssigners { return 0x81170102; }
sub PidLidAttendeeCriticalChange { return 0x00010040; }
sub PidLidDistributionListChecksum { return 0x804C0003; }
sub PidLidAppointmentCounterProposal { return 0x8257000B; }
@EXPORT=qw(PidLidPostRssItemLink PidLidDistributionListOneOffMembers PidLidTaskLastDelegate PidLidOptionalAttendees PidLidNoteColor PidLidIntendedBusyStatus PidLidAllAttendeesString PidLidSharingStatus PidLidFlagString PidLidAppointmentAuxiliaryFlags PidLidSideEffects PidLidNoteX PidLidSharingRemoteComment PidLidNonSendableTo PidLidConversationActionVersion PidLidTaskDueDate PidLidTaskHistory PidLidSharingAnonymity PidLidSharingTimeToLive PidLidDayInterval PidLidNonSendBccTrackStatus PidLidOldWhenStartWhole PidLidSharingConfigurationUrl PidLidFax3OriginalEntryId PidLidSharingPermissions PidLidDistributionListStream PidLidBilling PidLidClipEnd PidLidSharingRemoteType PidLidSharingResponseTime PidLidWorkAddress PidLidPostalAddressId PidLidLogDocumentSaved PidLidDayOfMonth PidLidAppointmentEndTime PidLidClassificationKeep PidLidPostRssChannelLink PidLidOwnerName PidLidRemoteStatus PidLidSharingDataRangeEnd PidLidSharingProviderExtension PidLidServerProcessingActions PidLidSharingRemoteStoreUid PidLidTaskAccepted PidLidAgingDontAgeMe PidLidAppointmentUpdateTime PidLidContactUserField2 PidLidMonthOfYearMask PidLidConferencingCheck PidLidReminderSet PidLidBusinessCardDisplayDefinition PidLidSharingStart PidLidAppointmentRecur PidLidRecurrenceType PidLidTaskStatusOnComplete PidLidSharingSyncFlags PidLidToDoTitle PidLidSharingRemoteUser PidLidVerbResponse PidLidDelegateMail PidLidTaskGlobalId PidLidAppointmentReplyTime PidLidSharingDetail PidLidContactLinkLinkRejectHistory PidLidClassificationGuid PidLidAppointmentProposalNumber PidLidLogType PidLidWhere PidLidAppointmentEndWhole PidLidContactUserField1 PidLidAutoProcessState PidLidConversationProcessed PidLidAppointmentStartTime PidLidTaskDeadOccurrence PidLidEmail3AddressType PidLidEmail3DisplayName PidLidTaskOrdinal PidLidPostRssSubscription PidLidSharingLocalType PidLidAppointmentStateFlags PidLidResponseStatus PidLidWorkAddressPostOfficeBox PidLidToDoSubOrdinal PidLidPostRssItemXml PidLidEmail2EmailAddress PidLidTaskMode PidLidWorkAddressCity PidLidSharingLastSyncTime PidLidEmail2DisplayName PidLidHtml PidLidIsSilent PidLidTaskOwner PidLidPostRssItemHash PidLidRecurrenceDuration PidLidOldWhenEndWhole PidLidTaskVersion PidLidSharingResponseType PidLidSharingLocalName PidLidTimeZoneStruct PidLidLinkedTaskItems PidLidSharingReciprocation PidLidHomeAddressCountryCode PidLidCollaborateDoc PidLidSharingLocalUid PidLidReminderTime PidLidTimeZoneDescription PidLidSharingRemotePath PidLidNoteY PidLidIsRecurring PidLidFOthersAppointment PidLidSharingWorkingHoursEnd PidLidClassificationDescription PidLidFax3AddressType PidLidExceptionReplaceTime PidLidReminderPlaySound PidLidAutoLog PidLidSingleBodyICal PidLidEmail3EmailAddress PidLidReferenceEntryId PidLidWorkAddressPostalCode PidLidSharingParentBindingEntryId PidLidSmartNoAttach PidLidEmail3OriginalDisplayName PidLidAddressBookProviderEmailList PidLidLogDocumentPosted PidLidNoEndDateFlag PidLidRequiredAttendees PidLidFax1OriginalDisplayName PidLidTaskRole PidLidAppointmentReplyName PidLidYomiCompanyName PidLidTaskFFixOffline PidLidICalendarDayOfWeekMask PidLidInstantMessagingAddress PidLidBirthdayEventEntryId PidLidTaskComplete PidLidOtherAddress PidLidTrustRecipientHighlights PidLidLogDocumentPrinted PidLidSharingBindingEntryId PidLidClassified PidLidOriginalStoreEntryId PidLidUseTnef PidLidInternetAccountName PidLidSharingRemoteLastModificationTime PidLidTeamTask PidLidFax1OriginalEntryId PidLidConversationActionMoveStoreEid PidLidTaskFCreator PidLidSharingStop PidLidEmail1DisplayName PidLidFax1EmailAddress PidLidConferencingType PidLidMonthOfYear PidLidSharingParticipants PidLidSharingIndexEntryId PidLidContactLinkSMTPAddressCache PidLidTaskActualEffort PidLidServerProcessed PidLidAllowExternalCheck PidLidCompanies PidLidFax2OriginalEntryId PidLidClassification PidLidFreeBusyLocation PidLidForwardNotificationRecipients PidLidSharingRangeEnd PidLidSharingInstanceGuid PidLidStartRecurrenceDate PidLidAppointmentProposedStartWhole PidLidPercentComplete PidLidEmail1OriginalEntryId PidLidDepartment PidLidDistributionListMembers PidLidSharingLastAutoSyncTime PidLidValidFlagStringProof PidLidLocation PidLidSharingFlags PidLidSharingLocalPath PidLidInfoPathFormName PidLidReferredBy PidLidSharingInitiatorSmtp PidLidHasPicture PidLidSharingRemoteUid PidLidToAttendeesString PidLidEmail2AddressType PidLidContactItemData PidLidWorkAddressStreet PidLidInboundICalStream PidLidPendingStateForTeamMailboxDocument PidLidDistributionListName PidLidTaskAcceptanceState PidLidSharingRangeStart PidLidToDoOrdinalDate PidLidFExceptionalAttendees PidLidTaskDateCompleted PidLidWeekInterval PidLidTaskStartDate PidLidTaskCustomFlags PidLidSharingWorkingHoursStart PidLidNonSendToTrackStatus PidLidSharingRemoteVersion PidLidContactLinkEntry PidLidHomeAddress PidLidClientIntent PidLidTaskOwnership PidLidSharingLocalLastModificationTime PidLidNonSendableCc PidLidFax3EmailAddress PidLidNonSendCcTrackStatus PidLidSharingRoamLog PidLidMeetingType PidLidRecurrencePattern PidLidCurrentVersionName PidLidAnniversaryEventEntryId PidLidForwardInstance PidLidSharingProviderGuid PidLidFax2EmailAddress PidLidNetShowUrl PidLidSharingOriginalMessageEntryId PidLidReminderDelta PidLidOccurrences PidLidFileUnder PidLidMeetingWorkspaceUrl PidLidAddressCountryCode PidLidTimeZone PidLidSharingRemoteCrc PidLidAppointmentStartWhole PidLidAppointmentDuration PidLidNoteWidth PidLidAppointmentTimeZoneDefinitionRecur PidLidAppointmentTimeZoneDefinitionEndDisplay PidLidSharingProviderUrl PidLidEmail1AddressType PidLidConversationActionLastAppliedTime PidLidNonSendableBcc PidLidContactUserField4 PidLidYomiLastName PidLidWorkAddressCountry PidLidSharingCapabilities PidLidBirthdayLocal PidLidConversationActionMoveFolderEid PidLidSharingSyncInterval PidLidTaskNoCompute PidLidTaskLastUser PidLidPostRssItemGuid PidLidFax2OriginalDisplayName PidLidCalendarType PidLidSharingRemoteName PidLidGlobalObjectId PidLidEndRecurrenceTime PidLidSharingRemoteByteSize PidLidSharingDataRangeStart PidLidYomiFirstName PidLidFlagRequest PidLidRecurring PidLidFax2AddressType PidLidSharingWorkingHoursDays PidLidContactLinkSearchKey PidLidMonthInterval PidLidSharingBrowseUrl PidLidAppointmentUnsendableRecipients PidLidContactLinkGlobalAddressListLinkState PidLidOtherAddressCountryCode PidLidWeddingAnniversaryLocal PidLidChangeHighlight PidLidOldRecurrenceType PidLidCategories PidLidFileUnderId PidLidAppointmentProposedEndWhole PidLidCommonEnd PidLidAppointmentColor PidLidPrivate PidLidAppointmentSequence PidLidSharingFolderEntryId PidLidReminderOverride PidLidOrganizerAlias PidLidSharingLocalStoreUid PidLidSharingLocalComment PidLidLogTypeDesc PidLidConversationActionMaxDeliveryTime PidLidReminderTimeTime PidLidFax3OriginalDisplayName PidLidAppointmentTimeZoneDefinitionStartDisplay PidLidAppointmentSequenceTime PidLidReminderFileParameter PidLidCommonStart PidLidTaskEstimatedEffort PidLidTaskMultipleRecipients PidLidReminderSignalTime PidLidAppointmentMessageClass PidLidYearInterval PidLidFileUnderList PidLidSharingRemoteMessageCount PidLidContactUserField3 PidLidAutoStartCheck PidLidContactLinkName PidLidAppointmentSubType PidLidBusinessCardCardPicture PidLidIsException PidLidSharingTimeToLiveAuto PidLidResourceAttendees PidLidSharingProviderName PidLidSpamOriginalFolder PidLidAppointmentProposedDuration PidLidVerbStream PidLidLogDuration PidLidAppointmentEndDate PidLidInternetAccountStamp PidLidEmail1OriginalDisplayName PidLidEmail2OriginalDisplayName PidLidAppointmentNotAllowPropose PidLidOwnerCriticalChange PidLidAppointmentLastSequence PidLidTaskAssigner PidLidSharingFlavor PidLidSharingFilter PidLidBusyStatus PidLidSharingInitiatorName PidLidWorkAddressState PidLidSharingExtensionXml PidLidAddressBookProviderArrayType PidLidCurrentVersion PidLidEmail2OriginalEntryId PidLidTaskRecurrence PidLidOldLocation PidLidWorkAddressCountryCode PidLidFax1AddressType PidLidLogFlags PidLidAppointmentStartDate PidLidPromptSendUpdate PidLidOnlinePassword PidLidReminderType PidLidContactLinkedGlobalAddressListEntryId PidLidContacts PidLidContactLinkGlobalAddressListLinkId PidLidTaskResetReminder PidLidEmail3OriginalEntryId PidLidTaskUpdates PidLidEndRecurrenceDate PidLidNoteHeight PidLidAutoFillLocation PidLidTaskState PidLidIsContactLinked PidLidLogStart PidLidFExceptionalBody PidLidLogEnd PidLidSharingWorkingHoursTimeZone PidLidTaskStatus PidLidClipStart PidLidLogDocumentRouted PidLidDirectory PidLidSharingInitiatorEntryId PidLidTaskFRecurring PidLidContactCharacterSet PidLidFInvited PidLidPostRssChannel PidLidCcAttendeesString PidLidReminderTimeDate PidLidTaskLastUpdate PidLidEmail1EmailAddress PidLidSharingRemotePass PidLidStartRecurrenceTime PidLidCleanGlobalObjectId PidLidTaskAssigners PidLidAttendeeCriticalChange PidLidDistributionListChecksum PidLidAppointmentCounterProposal);

1;
