
# This file is autogenerated from Microsoft documentation. Don't edit!
package Mail::Exchange::PidTagIDs;
use Exporter;
use vars qw(@ISA @EXPORTER);
@ISA=qw(Exporter);
# @EXPORT at the bottom because this file is autogenerated

sub PidTagRecipientEntryId { return 0x5FF70102; }
sub PidTagParentKey { return 0x00250102; }
sub PidTagSendRichInfo { return 0x3A40000B; }
sub PidTagFreeBusyRangeTimestamp { return 0x68680040; }
sub PidTagFreeBusyCountMonths { return 0x68690003; }
sub PidTagIsdnNumber { return 0x3A2D001F; }
sub PidTagOriginalMessageClass { return 0x004B001F; }
sub PidTagWlinkSaveStamp { return 0x68470003; }
sub PidTagBodyHtml { return 0x1013001F; }
sub PidTagCountry { return 0x3A26001F; }
sub PidTagMessageSizeExtended { return 0x0E080014; }
sub PidTagAddressBookExtensionAttribute4 { return 0x8030001F; }
sub PidTagAttachContentBase { return 0x3711001F; }
sub PidTagAddressBookContainerId { return 0xFFFD0003; }
sub PidTagInReplyToId { return 0x1042001F; }
sub PidTagLastModifierEntryId { return 0x3FFB0102; }
sub PidTagAddressBookHierarchicalParentDepartment { return 0x8C99000D; }
sub PidTagAttachEncoding { return 0x37020102; }
sub PidTagBusinessFaxNumber { return 0x3A24001F; }
sub PidTagScheduleInfoDisallowOverlappingAppts { return 0x686F000B; }
sub PidTagAddressBookHierarchicalIsHierarchicalGroup { return 0x8CDD000B; }
sub PidTagSentMailSvrEID { return 0x674000FB; }
sub PidTagArchivePeriod { return 0x301E0003; }
sub PidTagReportName { return 0x003A001F; }
sub PidTagOriginalAuthorEntryId { return 0x004C0102; }
sub PidTagComputerNetworkName { return 0x3A49001F; }
sub PidTagPostOfficeBox { return 0x3A2B001F; }
sub PidTagReceivedByEntryId { return 0x003F0102; }
sub PidTagCallId { return 0x6806001F; }
sub PidTagScheduleInfoDelegatorWantsInfo { return 0x684B000B; }
sub PidTagPublicFolderProxy { return 0x671D0102; }
sub PidTagAddressBookAuthorizedSenders { return 0x8CD8000D; }
sub PidTagMemberRights { return 0x66730003; }
sub PidTagAddressBookNetworkAddress { return 0x8170101F; }
sub PidTagSpokenName { return 0x8CC20102; }
sub PidTagNextSendAcct { return 0x0E29001F; }
sub PidTagScheduleInfoMonthsMerged { return 0x684F1003; }
sub PidTagKeyword { return 0x3A0B001F; }
sub PidTagStartDateEtc { return 0x301B0102; }
sub PidTagPersonalHomePage { return 0x3A50001F; }
sub PidTagParentEntryId { return 0x0E090102; }
sub PidTagOriginalSenderEntryId { return 0x005B0102; }
sub PidTagStoreState { return 0x340E0003; }
sub PidTagFreeBusyEntryIds { return 0x36E41102; }
sub PidTagAttachMimeTag { return 0x370E001F; }
sub PidTagScheduleInfoDelegateNames { return 0x6844101F; }
sub PidTagInternetMessageId { return 0x1035001F; }
sub PidTagFreeBusyPublishEnd { return 0x68480003; }
sub PidTagTemporaryDefaultDocument { return 0x3F20001F; }
sub PidTagFolderAssociatedContents { return 0x3610000D; }
sub PidTagAddressBookRoomCapacity { return 0x08070003; }
sub PidTagFlagCompleteTime { return 0x10910040; }
sub PidTagAddressBookHierarchicalDepartmentMembers { return 0x8C97000D; }
sub PidTagAttachTag { return 0x370A0102; }
sub PidTagRuleError { return 0x66480003; }
sub PidTagExpiryUnits { return 0x3FEE0003; }
sub PidTagConversationIndexTracking { return 0x3016000B; }
sub PidTagRuleSequence { return 0x66760003; }
sub PidTagDisplayNamePrefix { return 0x3A45001F; }
sub PidTagReadReceiptSearchKey { return 0x00530102; }
sub PidTagDepth { return 0x30050003; }
sub PidTagSentRepresentingEntryId { return 0x00410102; }
sub PidTagMessageEditorFormat { return 0x59090003; }
sub PidTagOfficeLocation { return 0x3A19001F; }
sub PidTagNativeBody { return 0x10160003; }
sub PidTagDeferredSendNumber { return 0x3FEB0003; }
sub PidTagAddressBookHierarchicalChildDepartments { return 0x8C9A000D; }
sub PidTagOriginalAuthorName { return 0x004D001F; }
sub PidTagIpmTaskEntryId { return 0x36D40102; }
sub PidTagOriginalSentRepresentingEmailAddress { return 0x0069001F; }
sub PidTagStartDate { return 0x00600040; }
sub PidTagAddressBookIsMaster { return 0xFFFB000B; }
sub PidTagReportEntryId { return 0x00450102; }
sub PidTagRuleLevel { return 0x66830003; }
sub PidTagAddressBookMessageId { return 0x674F0014; }
sub PidTagClientSubmitTime { return 0x00390040; }
sub PidTagThumbnailPhoto { return 0x8C9E0102; }
sub PidTagSenderSearchKey { return 0x0C1D0102; }
sub PidTagHome2TelephoneNumber { return 0x3A2F001F; }
sub PidTagAttachTransportName { return 0x370C001F; }
sub PidTagAddressBookManagerDistinguishedName { return 0x8005001F; }
sub PidTagIpmDraftsEntryId { return 0x36D70102; }
sub PidTagSwappedToDoStore { return 0x0E2C0102; }
sub PidTagManagerName { return 0x3A4E001F; }
sub PidTagHtml { return 0x10130102; }
sub PidTagHasAttachments { return 0x0E1B000B; }
sub PidTagBodyContentId { return 0x1015001F; }
sub PidTagSentRepresentingEmailAddress { return 0x0065001F; }
sub PidTagAddressBookDistributionListMemberSubmitAccepted { return 0x8073000D; }
sub PidTagOriginatorDeliveryReportRequested { return 0x0023000B; }
sub PidTagAddressBookObjectGuid { return 0x8C6D0102; }
sub PidTagMaximumSubmitMessageSize { return 0x666D0003; }
sub PidTagAddressBookExtensionAttribute11 { return 0x8C57001F; }
sub PidTagInstID { return 0x674D0014; }
sub PidTagRecipientDisplayName { return 0x5FF6001F; }
sub PidTagObjectType { return 0x0FFE0003; }
sub PidTagSearchFolderExpiration { return 0x683A0003; }
sub PidTagRuleActionType { return 0x66490003; }
sub PidTagRuleId { return 0x66740014; }
sub PidTagAddressBookObjectDistinguishedName { return 0x803C001F; }
sub PidTagHomeAddressPostalCode { return 0x3A5B001F; }
sub PidTagDisplayBcc { return 0x0E02001F; }
sub PidTagOtherAddressStreet { return 0x3A63001F; }
sub PidTagPostalAddress { return 0x3A15001F; }
sub PidTagSendInternetEncoding { return 0x3A710003; }
sub PidTagHasDeferredActionMessages { return 0x3FEA000B; }
sub PidTagDisplayCc { return 0x0E03001F; }
sub PidTagOrganizationalIdNumber { return 0x3A10001F; }
sub PidTagAddressBookOwnerBackLink { return 0x8024000D; }
sub PidTagRowid { return 0x30000003; }
sub PidTagMessageLocaleId { return 0x3FF10003; }
sub PidTagResponseRequested { return 0x0063000B; }
sub PidTagWlinkStoreEntryId { return 0x684E0102; }
sub PidTagSenderEntryId { return 0x0C190102; }
sub PidTagRwRulesStream { return 0x68020102; }
sub PidTagFolderId { return 0x67480014; }
sub PidTagAddressBookDeliveryContentLength { return 0x806A0003; }
sub PidTagAddressBookDisplayTypeExtended { return 0x8C930003; }
sub PidTagInitials { return 0x3A0A001F; }
sub PidTagPrimarySendAccount { return 0x0E28001F; }
sub PidTagScheduleInfoResourceType { return 0x68410003; }
sub PidTagSmtpAddress { return 0x39FE001F; }
sub PidTagOriginalSentRepresentingSearchKey { return 0x005F0102; }
sub PidTagJunkPermanentlyDelete { return 0x61020003; }
sub PidTagUserCertificate { return 0x3A220102; }
sub PidTagAddressType { return 0x3002001F; }
sub PidTagScheduleInfoDelegatorWantsCopy { return 0x6842000B; }
sub PidTagFollowupIcon { return 0x10950003; }
sub PidTagAddressBookX509Certificate { return 0x8C6A1102; }
sub PidTagReceivedRepresentingEmailAddress { return 0x0078001F; }
sub PidTagAssociated { return 0x67AA000B; }
sub PidTagHomeFaxNumber { return 0x3A25001F; }
sub PidTagViewDescriptorStrings { return 0x7002001F; }
sub PidTagOriginalSenderName { return 0x005A001F; }
sub PidTagReceivedBySearchKey { return 0x00510102; }
sub PidTagContentUnreadCount { return 0x36030003; }
sub PidTagOriginalSenderSearchKey { return 0x005C0102; }
sub PidTagInitialDetailsPane { return 0x3F080003; }
sub PidTagReplyRecipientEntries { return 0x004F0102; }
sub PidTagRadioTelephoneNumber { return 0x3A1D001F; }
sub PidTagUserX509Certificate { return 0x3A701102; }
sub PidTagVoiceMessageSenderName { return 0x6803001F; }
sub PidTagParentFolderId { return 0x67490014; }
sub PidTagAddressBookMember { return 0x8009000D; }
sub PidTagSubject { return 0x0037001F; }
sub PidTagAddressBookPhoneticCompanyName { return 0x8C91001F; }
sub PidTagRuleUserFlags { return 0x66780003; }
sub PidTagMid { return 0x674A0014; }
sub PidTagWlinkFlags { return 0x684A0003; }
sub PidTagHomeAddressStreet { return 0x3A5D001F; }
sub PidTagPagerTelephoneNumber { return 0x3A21001F; }
sub PidTagWlinkRecordKey { return 0x684D0102; }
sub PidTagRuleFolderEntryId { return 0x66510102; }
sub PidTagAddressBookExtensionAttribute1 { return 0x802D001F; }
sub PidTagReplyTemplateId { return 0x65C20102; }
sub PidTagReferredByName { return 0x3A47001F; }
sub PidTagAttachFlags { return 0x37140003; }
sub PidTagWlinkFolderType { return 0x684F0102; }
sub PidTagRecipientTrackStatus { return 0x5FFF0003; }
sub PidTagAddressBookHierarchicalRootDepartment { return 0x8C98001E; }
sub PidTagAddressBookPhoneticDepartmentName { return 0x8C90001F; }
sub PidTagOriginalDisplayTo { return 0x0074001F; }
sub PidTagSearchKey { return 0x300B0102; }
sub PidTagAddressBookExtensionAttribute15 { return 0x8C61001F; }
sub PidTagAdditionalRenEntryIds { return 0x36D81102; }
sub PidTagScheduleInfoFreeBusyBusy { return 0x68541102; }
sub PidTagDeletedOn { return 0x668F0040; }
sub PidTagReadReceiptAddressType { return 0x4029001F; }
sub PidTagPriority { return 0x00260003; }
sub PidTagRuleState { return 0x66770003; }
sub PidTagAddressBookDistributionListExternalMemberCount { return 0x8CE30003; }
sub PidTagOriginalSentRepresentingEntryId { return 0x005E0102; }
sub PidTagLastVerbExecutionTime { return 0x10820040; }
sub PidTagAttachRendering { return 0x37090102; }
sub PidTagBusinessHomePage { return 0x3A51001F; }
sub PidTagArchiveTag { return 0x30180102; }
sub PidTagUserEntryId { return 0x66190102; }
sub PidTagRuleMessageSequence { return 0x65F30003; }
sub PidTagReceivedRepresentingSearchKey { return 0x00520102; }
sub PidTagAccount { return 0x3A00001F; }
sub PidTagOtherAddressPostalCode { return 0x3A61001F; }
sub PidTagPrimaryTelephoneNumber { return 0x3A1A001F; }
sub PidTagLanguage { return 0x3A0C001F; }
sub PidTagICalendarReminderNextTime { return 0x10CA0040; }
sub PidTagScheduleInfoMonthsAway { return 0x68551003; }
sub PidTagAccessControlListData { return 0x3FE00102; }
sub PidTagAddressBookReports { return 0x800E000D; }
sub PidTagAddressBookDistributionListRejectMessagesFromDLMembers { return 0x8CDB000D; }
sub PidTagAddressBookFolderPathname { return 0x8004001F; }
sub PidTagSearchFolderLastUsed { return 0x68340003; }
sub PidTagReplyRequested { return 0x0C17000B; }
sub PidTagAttachmentFlags { return 0x7FFD0003; }
sub PidTagAttachMethod { return 0x37050003; }
sub PidTagMessageDeliveryTime { return 0x0E060040; }
sub PidTagLastModifierName { return 0x3FFA001F; }
sub PidTagTransportMessageHeaders { return 0x007D001F; }
sub PidTagDeferredDeliveryTime { return 0x000F0040; }
sub PidTagRemindersOnlineEntryId { return 0x36D50102; }
sub PidTagExpiryTime { return 0x00150040; }
sub PidTagDeleteAfterSubmit { return 0x0E01000B; }
sub PidTagAddressBookManageDistributionList { return 0x6704000D; }
sub PidTagOriginatorNonDeliveryReportRequested { return 0x0C08000B; }
sub PidTagMiddleName { return 0x3A44001F; }
sub PidTagSearchFolderTag { return 0x68470003; }
sub PidTagAttachPathname { return 0x3708001F; }
sub PidTagExtendedRuleMessageCondition { return 0x0E9A0102; }
sub PidTagJunkAddRecipientsToSafeSendersList { return 0x61030003; }
sub PidTagAccessLevel { return 0x0FF70003; }
sub PidTagHome2TelephoneNumbers { return 0x3A2F101F; }
sub PidTagAddressBookDisplayNamePrintable { return 0x39FF001F; }
sub PidTagMappingSignature { return 0x0FF80102; }
sub PidTagMobileTelephoneNumber { return 0x3A1C001F; }
sub PidTagBusinessTelephoneNumber { return 0x3A08001F; }
sub PidTagStoreSupportMask { return 0x340D0003; }
sub PidTagWlinkROGroupType { return 0x68920003; }
sub PidTagAttachLongFilename { return 0x3707001F; }
sub PidTagExtendedRuleSizeLimit { return 0x0E9B0003; }
sub PidTagRowType { return 0x0FF50003; }
sub PidTagViewDescriptorBinary { return 0x70010102; }
sub PidTagIpmContactEntryId { return 0x36D10102; }
sub PidTagProcessed { return 0x7D01000B; }
sub PidTagConflictEntryId { return 0x3FF00102; }
sub PidTagHomeAddressCountry { return 0x3A5A001F; }
sub PidTagAccess { return 0x0FF40003; }
sub PidTagTemplateid { return 0x39020102; }
sub PidTagOtherAddressCity { return 0x3A5F001F; }
sub PidTagCreationTime { return 0x30070040; }
sub PidTagBirthday { return 0x3A420040; }
sub PidTagWlinkType { return 0x68490003; }
sub PidTagRecipientFlags { return 0x5FFD0003; }
sub PidTagGender { return 0x3A4D0002; }
sub PidTagSurname { return 0x3A11001F; }
sub PidTagScheduleInfoFreeBusyMerged { return 0x68501102; }
sub PidTagRoamingDatatypes { return 0x7C060003; }
sub PidTagAddressBookExtensionAttribute10 { return 0x8036001F; }
sub PidTagExchangeNTSecurityDescriptor { return 0x0E840102; }
sub PidTagDefaultPostMessageClass { return 0x36E5001F; }
sub PidTagReportText { return 0x1001001F; }
sub PidTagTelecommunicationsDeviceForDeafTelephoneNumber { return 0x3A4B001F; }
sub PidTagContentCount { return 0x36020003; }
sub PidTagAttachmentContactPhoto { return 0x7FFF000B; }
sub PidTagNickname { return 0x3A4F001F; }
sub PidTagScheduleInfoMonthsBusy { return 0x68531003; }
sub PidTagAddressBookRoomDescription { return 0x0809001F; }
sub PidTagMessageSubmissionId { return 0x00470102; }
sub PidTagDeferredSendUnits { return 0x3FEC0003; }
sub PidTagConversationTopic { return 0x0070001F; }
sub PidTagWlinkEntryId { return 0x684C0102; }
sub PidTagDelegatedByRule { return 0x3FE3000B; }
sub PidTagSortLocaleId { return 0x67050003; }
sub PidTagDisplayTo { return 0x0E04001F; }
sub PidTagOriginalSenderAddressType { return 0x0066001F; }
sub PidTagOrdinalMost { return 0x36E20003; }
sub PidTagAttachPayloadProviderGuidString { return 0x3719001F; }
sub PidTagConversationIndex { return 0x00710102; }
sub PidTagContainerFlags { return 0x36000003; }
sub PidTagRetentionPeriod { return 0x301A0003; }
sub PidTagRuleProvider { return 0x6681001F; }
sub PidTagSearchFolderStorageType { return 0x68460003; }
sub PidTagMailboxOwnerName { return 0x661C001F; }
sub PidTagSchedulePlusFreeBusyEntryId { return 0x66220102; }
sub PidTagListHelp { return 0x1043001F; }
sub PidTagOriginalSenderEmailAddress { return 0x0067001F; }
sub PidTagAttachExtension { return 0x3703001F; }
sub PidTagSourceKey { return 0x65E00102; }
sub PidTagInConflict { return 0x666C000B; }
sub PidTagStoreEntryId { return 0x0FFB0102; }
sub PidTagReceivedRepresentingAddressType { return 0x0077001F; }
sub PidTagSwappedToDoData { return 0x0E2D0102; }
sub PidTagHomeAddressStateOrProvince { return 0x3A5C001F; }
sub PidTagAddressBookUnauthorizedSenders { return 0x8CD9000D; }
sub PidTagSensitivity { return 0x00360003; }
sub PidTagNonReceiptNotificationRequested { return 0x0C06000B; }
sub PidTagPrimaryFaxNumber { return 0x3A23001F; }
sub PidTagReportDisposition { return 0x0080001F; }
sub PidTagNormalizedSubject { return 0x0E1D001F; }
sub PidTagSentRepresentingAddressType { return 0x0064001F; }
sub PidTagAddressBookDistributionListMemberCount { return 0x8CE20003; }
sub PidTagAddressBookOrganizationalUnitRootDistinguishedName { return 0x8CA8001F; }
sub PidTagFlatUrlName { return 0x670E001F; }
sub PidTagAddressBookExtensionAttribute14 { return 0x8C60001F; }
sub PidTagOriginalEntryId { return 0x3A120102; }
sub PidTagAutoForwarded { return 0x0005000B; }
sub PidTagLocality { return 0x3A27001F; }
sub PidTagMessageAttachments { return 0x0E13000D; }
sub PidTagSentRepresentingName { return 0x0042001F; }
sub PidTagAttachContentLocation { return 0x3713001F; }
sub PidTagVoiceMessageDuration { return 0x68010003; }
sub PidTagViewDescriptorName { return 0x7006001F; }
sub PidTagEmailAddress { return 0x3003001F; }
sub PidTagUrlName { return 0x6707001F; }
sub PidTagAttributeReadOnly { return 0x10F6000B; }
sub PidTagAttachSize { return 0x0E200003; }
sub PidTagRuleMessageName { return 0x65EC001F; }
sub PidTagAddressBookExtensionAttribute5 { return 0x8031001F; }
sub PidTagOriginalDisplayCc { return 0x0073001F; }
sub PidTagGatewayNeedsToRefresh { return 0x6846000B; }
sub PidTagRoamingDictionary { return 0x7C070102; }
sub PidTagAddressBookIsMemberOfDistributionList { return 0x8008001E; }
sub PidTagAddressBookExtensionAttribute2 { return 0x802E001F; }
sub PidTagDisplayTypeEx { return 0x39050003; }
sub PidTagAddressBookRoomContainers { return 0x8C96101F; }
sub PidTagLocaleId { return 0x66A10003; }
sub PidTagReceivedByAddressType { return 0x0075001F; }
sub PidTagAddressBookPhoneticGivenName { return 0x8C8E001F; }
sub PidTagAddressBookProxyAddresses { return 0x800F101F; }
sub PidTagRuleActions { return 0x668000FE; }
sub PidTagFtpSite { return 0x3A4C001F; }
sub PidTagReceivedRepresentingEntryId { return 0x00430102; }
sub PidTagOriginalSensitivity { return 0x002E0003; }
sub PidTagAddressBookExtensionAttribute9 { return 0x8035001F; }
sub PidTagSearchFolderTemplateId { return 0x68410003; }
sub PidTagAssistant { return 0x3A30001F; }
sub PidTagTransmittableDisplayName { return 0x3A20001F; }
sub PidTagRetentionDate { return 0x301C0040; }
sub PidTagOtherTelephoneNumber { return 0x3A1F001F; }
sub PidTagPredecessorChangeList { return 0x65E30102; }
sub PidTagAddressBookExtensionAttribute12 { return 0x8C58001F; }
sub PidTagLastModificationTime { return 0x30080040; }
sub PidTagHasNamedProperties { return 0x664A000B; }
sub PidTagGovernmentIdNumber { return 0x3A07001F; }
sub PidTagListSubscribe { return 0x1044001F; }
sub PidTagBody { return 0x1000001F; }
sub PidTagAddressBookDistributionListMemberSubmitRejected { return 0x8CDA000D; }
sub PidTagMessageHandlingSystemCommonName { return 0x3A0F001F; }
sub PidTagMessageRecipients { return 0x0E12000D; }
sub PidTagHomeTelephoneNumber { return 0x3A09001F; }
sub PidTagWlinkClientID { return 0x68900048; }
sub PidTagContainerHierarchy { return 0x360E000D; }
sub PidTagEndDate { return 0x00610040; }
sub PidTagPublicFolderAdministrativeDescription { return 0x671C001F; }
sub PidTagSenderAddressType { return 0x0C1E001F; }
sub PidTagGeneration { return 0x3A05001F; }
sub PidTagRetentionFlags { return 0x301D0003; }
sub PidTagJunkThreshold { return 0x61010003; }
sub PidTagScheduleInfoAppointmentTombstone { return 0x686A0102; }
sub PidTagArchiveDate { return 0x301F0040; }
sub PidTagRuleIds { return 0x66750102; }
sub PidTagScriptData { return 0x00040102; }
sub PidTagAddressBookExtensionAttribute3 { return 0x802F001F; }
sub PidTagWlinkGroupName { return 0x6851001F; }
sub PidTagScheduleInfoMonthsTentative { return 0x68511003; }
sub PidTagScheduleInfoFreeBusyTentative { return 0x68521102; }
sub PidTagContentFilterSpamConfidenceLevel { return 0x40760003; }
sub PidTagReadReceiptRequested { return 0x0029000B; }
sub PidTagSenderSmtpAddress { return 0x5D01001F; }
sub PidTagWlinkGroupClsid { return 0x68500102; }
sub PidTagUrlCompName { return 0x10F3001F; }
sub PidTagAttachPayloadClass { return 0x371A001F; }
sub PidTagSenderTelephoneNumber { return 0x6802001F; }
sub PidTagConversationId { return 0x30130102; }
sub PidTagRuleMessageUserFlags { return 0x65EA0003; }
sub PidTagMessageCodepage { return 0x3FFD0003; }
sub PidTagRights { return 0x66390003; }
sub PidTagSentRepresentingFlags { return 0x401A0003; }
sub PidTagInternetMailOverrideFormat { return 0x59020003; }
sub PidTagProviderSubmitTime { return 0x00480040; }
sub PidTagNormalMessageSize { return 0x66B30003; }
sub PidTagMessageToMe { return 0x0057000B; }
sub PidTagTitle { return 0x3A17001F; }
sub PidTagReceivedByName { return 0x0040001F; }
sub PidTagReadReceiptEntryId { return 0x00460102; }
sub PidTagLocalCommitTime { return 0x67090040; }
sub PidTagResolveMethod { return 0x3FE70003; }
sub PidTagDamOriginalEntryId { return 0x66460102; }
sub PidTagSenderIdStatus { return 0x40790003; }
sub PidTagOriginalDeliveryTime { return 0x00550040; }
sub PidTagScheduleInfoDelegateEntryIds { return 0x68451102; }
sub PidTagRead { return 0x0E69000B; }
sub PidTagScheduleInfoAutoAcceptAppointments { return 0x686D000B; }
sub PidTagSentRepresentingSearchKey { return 0x003B0102; }
sub PidTagAnr { return 0x360C001F; }
sub PidTagAttachmentHidden { return 0x7FFE000B; }
sub PidTagLastVerbExecuted { return 0x10810003; }
sub PidTagRecipientOrder { return 0x5FDF0003; }
sub PidTagBusiness2TelephoneNumbers { return 0x3A1B101F; }
sub PidTagSearchFolderRecreateInfo { return 0x68440102; }
sub PidTagContainerContents { return 0x360F000D; }
sub PidTagStreetAddress { return 0x3A29001F; }
sub PidTagExceptionStartTime { return 0x7FFB0040; }
sub PidTagRecipientProposed { return 0x5FE1000B; }
sub PidTagCodePageId { return 0x66C30003; }
sub PidTagAutoForwardComment { return 0x0004001F; }
sub PidTagOriginalSubject { return 0x0049001F; }
sub PidTagMemberName { return 0x6672001F; }
sub PidTagReceivedRepresentingName { return 0x0044001F; }
sub PidTagRecipientTrackStatusTime { return 0x5FFB0040; }
sub PidTagMimeSkeleton { return 0x64F00102; }
sub PidTagRecipientResourceState { return 0x5FDE0003; }
sub PidTagAddressBookParentEntryId { return 0xFFFC0102; }
sub PidTagSpouseName { return 0x3A48001F; }
sub PidTagMessageRecipientMe { return 0x0059000B; }
sub PidTagRuleProviderData { return 0x66840102; }
sub PidTagAddressBookManager { return 0x8005000D; }
sub PidTagDeferredSendTime { return 0x3FEF0040; }
sub PidTagTargetEntryId { return 0x30100102; }
sub PidTagAlternateRecipientAllowed { return 0x0002000B; }
sub PidTagHobbies { return 0x3A43001F; }
sub PidTagExtendedRuleMessageActions { return 0x0E990102; }
sub PidTagSubfolders { return 0x360A000B; }
sub PidTagProfession { return 0x3A46001F; }
sub PidTagWlinkAddressBookEID { return 0x68540102; }
sub PidTagRecipientType { return 0x0C150003; }
sub PidTagMessageClass { return 0x001A001F; }
sub PidTagFlagStatus { return 0x10900003; }
sub PidTagRecordKey { return 0x0FF90102; }
sub PidTagReplyRecipientNames { return 0x0050001F; }
sub PidTagMessageCcMe { return 0x0058000B; }
sub PidTagOfflineAddressBookMessageClass { return 0x68030003; }
sub PidTagAttachContentId { return 0x3712001F; }
sub PidTagTelexNumber { return 0x3A2C001F; }
sub PidTagSenderName { return 0x0C1A001F; }
sub PidTagViewDescriptorVersion { return 0x70070003; }
sub PidTagMessageSize { return 0x0E080003; }
sub PidTagInternetArticleNumber { return 0x0E230003; }
sub PidTagBlockStatus { return 0x10960003; }
sub PidTagVoiceMessageAttachmentOrder { return 0x6805001F; }
sub PidTagReportTag { return 0x00310102; }
sub PidTagAutoResponseSuppress { return 0x3FDF0003; }
sub PidTagStateOrProvince { return 0x3A28001F; }
sub PidTagHomeAddressPostOfficeBox { return 0x3A5E001F; }
sub PidTagChangeNumber { return 0x67A40014; }
sub PidTagMemberId { return 0x66710014; }
sub PidTagReportTime { return 0x00320040; }
sub PidTagCreatorEntryId { return 0x3FF90102; }
sub PidTagOfflineAddressBookContainerGuid { return 0x6802001E; }
sub PidTagReadReceiptEmailAddress { return 0x402A001F; }
sub PidTagFreeBusyPublishStart { return 0x68470003; }
sub PidTagCallbackTelephoneNumber { return 0x3A02001F; }
sub PidTagSearchFolderId { return 0x68420102; }
sub PidTagReportDispositionMode { return 0x0081001F; }
sub PidTagExceptionReplaceTime { return 0x7FF90040; }
sub PidTagCustomerId { return 0x3A4A001F; }
sub PidTagResponsibility { return 0x0E0F000B; }
sub PidTagReplyTime { return 0x00300040; }
sub PidTagAddressBookSeniorityIndex { return 0x8CA00003; }
sub PidTagScheduleInfoFreeBusy { return 0x686C0102; }
sub PidTagLocation { return 0x3A0D001F; }
sub PidTagPolicyTag { return 0x30190102; }
sub PidTagRecipientProposedEndTime { return 0x5FE40040; }
sub PidTagInstanceKey { return 0x0FF60102; }
sub PidTagSecurityDescriptorAsXml { return 0x0E6A001F; }
sub PidTagRecipientReassignmentProhibited { return 0x002B000B; }
sub PidTagBusiness2TelephoneNumber { return 0x3A1B001F; }
sub PidTagAddressBookPhoneticDisplayName { return 0x8C92001F; }
sub PidTagAddressBookPublicDelegates { return 0x8015000D; }
sub PidTagRenderingPosition { return 0x370B0003; }
sub PidTagChangeKey { return 0x65E20102; }
sub PidTagIpmAppointmentEntryId { return 0x36D00102; }
sub PidTagAddressBookTargetAddress { return 0x8011001F; }
sub PidTagWlinkAddressBookStoreEID { return 0x68910102; }
sub PidTagRuleMessageProvider { return 0x65EB001F; }
sub PidTagIpmJournalEntryId { return 0x36D20102; }
sub PidTagOtherAddressStateOrProvince { return 0x3A62001F; }
sub PidTagRuleName { return 0x6682001F; }
sub PidTagToDoItemFlags { return 0x0E2B0003; }
sub PidTagWlinkCalendarColor { return 0x68530003; }
sub PidTagContainerClass { return 0x3613001F; }
sub PidTagSubjectPrefix { return 0x003D001F; }
sub PidTagMailboxOwnerEntryId { return 0x661B0102; }
sub PidTagCurrentDraftEntryId { return 0x00000102; }
sub PidTagWeddingAnniversary { return 0x3A410040; }
sub PidTagAttachDataBinary { return 0x37010102; }
sub PidTagAttachNumber { return 0x0E210003; }
sub PidTagRuleMessageLevel { return 0x65ED0003; }
sub PidTagDisplayType { return 0x39000003; }
sub PidTagOriginalMessageId { return 0x1046001F; }
sub PidTagRecipientProposedStartTime { return 0x5FE30040; }
sub PidTagPurportedSenderDomain { return 0x4083001F; }
sub PidTagClientActions { return 0x66450102; }
sub PidTagHomeAddressCity { return 0x3A59001F; }
sub PidTagCompanyName { return 0x3A160000; }
sub PidTagTextAttachmentCharset { return 0x371B001F; }
sub PidTagTemplateData { return 0x00010102; }
sub PidTagAddressBookPhoneticSurname { return 0x8C8F001F; }
sub PidTagRoamingXmlStream { return 0x7C080102; }
sub PidTagProhibitReceiveQuota { return 0x666A0003; }
sub PidTagAddressBookExtensionAttribute7 { return 0x8033001F; }
sub PidTagDeferredActionMessageOriginalEntryId { return 0x674100FB; }
sub PidTagExtendedFolderFlags { return 0x36DA0102; }
sub PidTagFaxNumberOfPages { return 0x68040003; }
sub PidTagAddressBookEntryId { return 0x663B0102; }
sub PidTagFreeBusyMessageEmailAddress { return 0x6849001F; }
sub PidTagAttributeHidden { return 0x10F4000B; }
sub PidTagCarTelephoneNumber { return 0x3A1E001F; }
sub PidTagOriginalSubmitTime { return 0x004E0040; }
sub PidTagOfflineAddressBookSequence { return 0x68010003; }
sub PidTagAddressBookOwner { return 0x800C000D; }
sub PidTagIpmNoteEntryId { return 0x36D30102; }
sub PidTagAdditionalRenEntryIdsEx { return 0x36D90102; }
sub PidTagReportSearchKey { return 0x00540102; }
sub PidTagTnefCorrelationKey { return 0x007F0102; }
sub PidTagDelegateFlags { return 0x686B1003; }
sub PidTagJunkIncludeContacts { return 0x61000003; }
sub PidTagListUnsubscribe { return 0x1045001F; }
sub PidTagAddressBookSenderHintTranslations { return 0x8CAC101F; }
sub PidTagWlinkGroupHeaderID { return 0x68420048; }
sub PidTagOfflineAddressBookDistinguishedName { return 0x6804001E; }
sub PidTagInternetCodepage { return 0x3FDE0003; }
sub PidTagAddressBookHomeMessageDatabase { return 0x8006001E; }
sub PidTagOriginalSentRepresentingAddressType { return 0x0068001F; }
sub PidTagScheduleInfoDisallowRecurringAppts { return 0x686E000B; }
sub PidTagRtfCompressed { return 0x10090102; }
sub PidTagRuleCondition { return 0x667900FD; }
sub PidTagImportance { return 0x00170003; }
sub PidTagPostalCode { return 0x3A2A001F; }
sub PidTagRuleMessageState { return 0x65E90003; }
sub PidTagMessageStatus { return 0x0E170003; }
sub PidTagTrustSender { return 0x0E790003; }
sub PidTagOtherAddressCountry { return 0x3A60001F; }
sub PidTagJunkPhishingEnableLinks { return 0x6107000B; }
sub PidTagAddressBookHierarchicalShowInDepartments { return 0x8C94000D; }
sub PidTagAssistantTelephoneNumber { return 0x3A2E001F; }
sub PidTagOutOfOfficeState { return 0x661D000B; }
sub PidTagAttachFilename { return 0x3704001F; }
sub PidTagComment { return 0x3004001F; }
sub PidTagCreatorName { return 0x3FF8001F; }
sub PidTagReceivedByEmailAddress { return 0x0076001F; }
sub PidTagHierarchyChangeNumber { return 0x663E0003; }
sub PidTagRuleMessageProviderData { return 0x65EE0102; }
sub PidTagBodyContentLocation { return 0x1014001F; }
sub PidTagIconIndex { return 0x10800003; }
sub PidTagScheduleInfoDontMailDelegates { return 0x6843000B; }
sub PidTagOscSyncEnabled { return 0x7C24000B; }
sub PidTagCdoRecurrenceid { return 0x10C50040; }
sub PidTagCompanyMainTelephoneNumber { return 0x3A57001F; }
sub PidTagExceptionEndTime { return 0x7FFC0040; }
sub PidTagSubfolder { return 0x6708000B; }
sub PidTagScheduleInfoDelegateNamesW { return 0x684A101F; }
sub PidTagOriginalDisplayBcc { return 0x0072001F; }
sub PidTagHasRules { return 0x663A000B; }
sub PidTagGivenName { return 0x3A06001F; }
sub PidTagAddressBookExtensionAttribute13 { return 0x8C59001F; }
sub PidTagAddressBookExtensionAttribute8 { return 0x8034001F; }
sub PidTagICalendarEndTime { return 0x10C40040; }
sub PidTagSenderEmailAddress { return 0x0C1F001F; }
sub PidTagFolderType { return 0x36010003; }
sub PidTagScheduleInfoFreeBusyAway { return 0x68561102; }
sub PidTagOriginalSentRepresentingName { return 0x005D001F; }
sub PidTagSearchFolderEfpFlags { return 0x68480003; }
sub PidTagOfflineAddressBookTruncatedProperties { return 0x68051003; }
sub PidTagChildrensNames { return 0x3A58101F; }
sub PidTagReadReceiptName { return 0x402B001F; }
sub PidTagWlinkOrdinal { return 0x684B0102; }
sub PidTagProhibitSendQuota { return 0x666E0003; }
sub PidTagDisplayName { return 0x3001001F; }
sub PidTagSelectable { return 0x3609000B; }
sub PidTagSearchFolderDefinition { return 0x68450102; }
sub PidTagExpiryNumber { return 0x3FED0003; }
sub PidTagWlinkSection { return 0x68520003; }
sub PidTagDepartmentName { return 0x3A18001F; }
sub PidTagOtherAddressPostOfficeBox { return 0x3A64001F; }
sub PidTagRtfInSync { return 0x0E1F000B; }
sub PidTagDamBackPatched { return 0x6647000B; }
sub PidTagOwnerAppointmentId { return 0x00620003; }
sub PidTagAddressBookExtensionAttribute6 { return 0x8032001F; }
sub PidTagAttachLongPathname { return 0x370D001F; }
sub PidTagICalendarStartTime { return 0x10C30040; }
sub PidTagRuleActionNumber { return 0x66500003; }
sub PidTagInstanceNum { return 0x674E0003; }
sub PidTagMessageFlags { return 0x0E070003; }
sub PidTagInternetReferences { return 0x1039001F; }
sub PidTagAttachAdditionalInformation { return 0x370F0102; }
sub PidTagParentSourceKey { return 0x65E10102; }
sub PidTagAttachmentLinkId { return 0x7FFA0003; }
sub PidTagAttachDataObject { return 0x3701000D; }
sub PidTagOfflineAddressBookName { return 0x6800001F; }
sub PidTagEntryId { return 0x0FFF0102; }
sub PidTagAddressBookModerationEnabled { return 0x8CB5000B; }
@EXPORT=qw(PidTagRecipientEntryId PidTagParentKey PidTagSendRichInfo PidTagFreeBusyRangeTimestamp PidTagFreeBusyCountMonths PidTagIsdnNumber PidTagOriginalMessageClass PidTagWlinkSaveStamp PidTagBodyHtml PidTagCountry PidTagMessageSizeExtended PidTagAddressBookExtensionAttribute4 PidTagAttachContentBase PidTagAddressBookContainerId PidTagInReplyToId PidTagLastModifierEntryId PidTagAddressBookHierarchicalParentDepartment PidTagAttachEncoding PidTagBusinessFaxNumber PidTagScheduleInfoDisallowOverlappingAppts PidTagAddressBookHierarchicalIsHierarchicalGroup PidTagSentMailSvrEID PidTagArchivePeriod PidTagReportName PidTagOriginalAuthorEntryId PidTagComputerNetworkName PidTagPostOfficeBox PidTagReceivedByEntryId PidTagCallId PidTagScheduleInfoDelegatorWantsInfo PidTagPublicFolderProxy PidTagAddressBookAuthorizedSenders PidTagMemberRights PidTagAddressBookNetworkAddress PidTagSpokenName PidTagNextSendAcct PidTagScheduleInfoMonthsMerged PidTagKeyword PidTagStartDateEtc PidTagPersonalHomePage PidTagParentEntryId PidTagOriginalSenderEntryId PidTagStoreState PidTagFreeBusyEntryIds PidTagAttachMimeTag PidTagScheduleInfoDelegateNames PidTagInternetMessageId PidTagFreeBusyPublishEnd PidTagTemporaryDefaultDocument PidTagFolderAssociatedContents PidTagAddressBookRoomCapacity PidTagFlagCompleteTime PidTagAddressBookHierarchicalDepartmentMembers PidTagAttachTag PidTagRuleError PidTagExpiryUnits PidTagConversationIndexTracking PidTagRuleSequence PidTagDisplayNamePrefix PidTagReadReceiptSearchKey PidTagDepth PidTagSentRepresentingEntryId PidTagMessageEditorFormat PidTagOfficeLocation PidTagNativeBody PidTagDeferredSendNumber PidTagAddressBookHierarchicalChildDepartments PidTagOriginalAuthorName PidTagIpmTaskEntryId PidTagOriginalSentRepresentingEmailAddress PidTagStartDate PidTagAddressBookIsMaster PidTagReportEntryId PidTagRuleLevel PidTagAddressBookMessageId PidTagClientSubmitTime PidTagThumbnailPhoto PidTagSenderSearchKey PidTagHome2TelephoneNumber PidTagAttachTransportName PidTagAddressBookManagerDistinguishedName PidTagIpmDraftsEntryId PidTagSwappedToDoStore PidTagManagerName PidTagHtml PidTagHasAttachments PidTagBodyContentId PidTagSentRepresentingEmailAddress PidTagAddressBookDistributionListMemberSubmitAccepted PidTagOriginatorDeliveryReportRequested PidTagAddressBookObjectGuid PidTagMaximumSubmitMessageSize PidTagAddressBookExtensionAttribute11 PidTagInstID PidTagRecipientDisplayName PidTagObjectType PidTagSearchFolderExpiration PidTagRuleActionType PidTagRuleId PidTagAddressBookObjectDistinguishedName PidTagHomeAddressPostalCode PidTagDisplayBcc PidTagOtherAddressStreet PidTagPostalAddress PidTagSendInternetEncoding PidTagHasDeferredActionMessages PidTagDisplayCc PidTagOrganizationalIdNumber PidTagAddressBookOwnerBackLink PidTagRowid PidTagMessageLocaleId PidTagResponseRequested PidTagWlinkStoreEntryId PidTagSenderEntryId PidTagRwRulesStream PidTagFolderId PidTagAddressBookDeliveryContentLength PidTagAddressBookDisplayTypeExtended PidTagInitials PidTagPrimarySendAccount PidTagScheduleInfoResourceType PidTagSmtpAddress PidTagOriginalSentRepresentingSearchKey PidTagJunkPermanentlyDelete PidTagUserCertificate PidTagAddressType PidTagScheduleInfoDelegatorWantsCopy PidTagFollowupIcon PidTagAddressBookX509Certificate PidTagReceivedRepresentingEmailAddress PidTagAssociated PidTagHomeFaxNumber PidTagViewDescriptorStrings PidTagOriginalSenderName PidTagReceivedBySearchKey PidTagContentUnreadCount PidTagOriginalSenderSearchKey PidTagInitialDetailsPane PidTagReplyRecipientEntries PidTagRadioTelephoneNumber PidTagUserX509Certificate PidTagVoiceMessageSenderName PidTagParentFolderId PidTagAddressBookMember PidTagSubject PidTagAddressBookPhoneticCompanyName PidTagRuleUserFlags PidTagMid PidTagWlinkFlags PidTagHomeAddressStreet PidTagPagerTelephoneNumber PidTagWlinkRecordKey PidTagRuleFolderEntryId PidTagAddressBookExtensionAttribute1 PidTagReplyTemplateId PidTagReferredByName PidTagAttachFlags PidTagWlinkFolderType PidTagRecipientTrackStatus PidTagAddressBookHierarchicalRootDepartment PidTagAddressBookPhoneticDepartmentName PidTagOriginalDisplayTo PidTagSearchKey PidTagAddressBookExtensionAttribute15 PidTagAdditionalRenEntryIds PidTagScheduleInfoFreeBusyBusy PidTagDeletedOn PidTagReadReceiptAddressType PidTagPriority PidTagRuleState PidTagAddressBookDistributionListExternalMemberCount PidTagOriginalSentRepresentingEntryId PidTagLastVerbExecutionTime PidTagAttachRendering PidTagBusinessHomePage PidTagArchiveTag PidTagUserEntryId PidTagRuleMessageSequence PidTagReceivedRepresentingSearchKey PidTagAccount PidTagOtherAddressPostalCode PidTagPrimaryTelephoneNumber PidTagLanguage PidTagICalendarReminderNextTime PidTagScheduleInfoMonthsAway PidTagAccessControlListData PidTagAddressBookReports PidTagAddressBookDistributionListRejectMessagesFromDLMembers PidTagAddressBookFolderPathname PidTagSearchFolderLastUsed PidTagReplyRequested PidTagAttachmentFlags PidTagAttachMethod PidTagMessageDeliveryTime PidTagLastModifierName PidTagTransportMessageHeaders PidTagDeferredDeliveryTime PidTagRemindersOnlineEntryId PidTagExpiryTime PidTagDeleteAfterSubmit PidTagAddressBookManageDistributionList PidTagOriginatorNonDeliveryReportRequested PidTagMiddleName PidTagSearchFolderTag PidTagAttachPathname PidTagExtendedRuleMessageCondition PidTagJunkAddRecipientsToSafeSendersList PidTagAccessLevel PidTagHome2TelephoneNumbers PidTagAddressBookDisplayNamePrintable PidTagMappingSignature PidTagMobileTelephoneNumber PidTagBusinessTelephoneNumber PidTagStoreSupportMask PidTagWlinkROGroupType PidTagAttachLongFilename PidTagExtendedRuleSizeLimit PidTagRowType PidTagViewDescriptorBinary PidTagIpmContactEntryId PidTagProcessed PidTagConflictEntryId PidTagHomeAddressCountry PidTagAccess PidTagTemplateid PidTagOtherAddressCity PidTagCreationTime PidTagBirthday PidTagWlinkType PidTagRecipientFlags PidTagGender PidTagSurname PidTagScheduleInfoFreeBusyMerged PidTagRoamingDatatypes PidTagAddressBookExtensionAttribute10 PidTagExchangeNTSecurityDescriptor PidTagDefaultPostMessageClass PidTagReportText PidTagTelecommunicationsDeviceForDeafTelephoneNumber PidTagContentCount PidTagAttachmentContactPhoto PidTagNickname PidTagScheduleInfoMonthsBusy PidTagAddressBookRoomDescription PidTagMessageSubmissionId PidTagDeferredSendUnits PidTagConversationTopic PidTagWlinkEntryId PidTagDelegatedByRule PidTagSortLocaleId PidTagDisplayTo PidTagOriginalSenderAddressType PidTagOrdinalMost PidTagAttachPayloadProviderGuidString PidTagConversationIndex PidTagContainerFlags PidTagRetentionPeriod PidTagRuleProvider PidTagSearchFolderStorageType PidTagMailboxOwnerName PidTagSchedulePlusFreeBusyEntryId PidTagListHelp PidTagOriginalSenderEmailAddress PidTagAttachExtension PidTagSourceKey PidTagInConflict PidTagStoreEntryId PidTagReceivedRepresentingAddressType PidTagSwappedToDoData PidTagHomeAddressStateOrProvince PidTagAddressBookUnauthorizedSenders PidTagSensitivity PidTagNonReceiptNotificationRequested PidTagPrimaryFaxNumber PidTagReportDisposition PidTagNormalizedSubject PidTagSentRepresentingAddressType PidTagAddressBookDistributionListMemberCount PidTagAddressBookOrganizationalUnitRootDistinguishedName PidTagFlatUrlName PidTagAddressBookExtensionAttribute14 PidTagOriginalEntryId PidTagAutoForwarded PidTagLocality PidTagMessageAttachments PidTagSentRepresentingName PidTagAttachContentLocation PidTagVoiceMessageDuration PidTagViewDescriptorName PidTagEmailAddress PidTagUrlName PidTagAttributeReadOnly PidTagAttachSize PidTagRuleMessageName PidTagAddressBookExtensionAttribute5 PidTagOriginalDisplayCc PidTagGatewayNeedsToRefresh PidTagRoamingDictionary PidTagAddressBookIsMemberOfDistributionList PidTagAddressBookExtensionAttribute2 PidTagDisplayTypeEx PidTagAddressBookRoomContainers PidTagLocaleId PidTagReceivedByAddressType PidTagAddressBookPhoneticGivenName PidTagAddressBookProxyAddresses PidTagRuleActions PidTagFtpSite PidTagReceivedRepresentingEntryId PidTagOriginalSensitivity PidTagAddressBookExtensionAttribute9 PidTagSearchFolderTemplateId PidTagAssistant PidTagTransmittableDisplayName PidTagRetentionDate PidTagOtherTelephoneNumber PidTagPredecessorChangeList PidTagAddressBookExtensionAttribute12 PidTagLastModificationTime PidTagHasNamedProperties PidTagGovernmentIdNumber PidTagListSubscribe PidTagBody PidTagAddressBookDistributionListMemberSubmitRejected PidTagMessageHandlingSystemCommonName PidTagMessageRecipients PidTagHomeTelephoneNumber PidTagWlinkClientID PidTagContainerHierarchy PidTagEndDate PidTagPublicFolderAdministrativeDescription PidTagSenderAddressType PidTagGeneration PidTagRetentionFlags PidTagJunkThreshold PidTagScheduleInfoAppointmentTombstone PidTagArchiveDate PidTagRuleIds PidTagScriptData PidTagAddressBookExtensionAttribute3 PidTagWlinkGroupName PidTagScheduleInfoMonthsTentative PidTagScheduleInfoFreeBusyTentative PidTagContentFilterSpamConfidenceLevel PidTagReadReceiptRequested PidTagSenderSmtpAddress PidTagWlinkGroupClsid PidTagUrlCompName PidTagAttachPayloadClass PidTagSenderTelephoneNumber PidTagConversationId PidTagRuleMessageUserFlags PidTagMessageCodepage PidTagRights PidTagSentRepresentingFlags PidTagInternetMailOverrideFormat PidTagProviderSubmitTime PidTagNormalMessageSize PidTagMessageToMe PidTagTitle PidTagReceivedByName PidTagReadReceiptEntryId PidTagLocalCommitTime PidTagResolveMethod PidTagDamOriginalEntryId PidTagSenderIdStatus PidTagOriginalDeliveryTime PidTagScheduleInfoDelegateEntryIds PidTagRead PidTagScheduleInfoAutoAcceptAppointments PidTagSentRepresentingSearchKey PidTagAnr PidTagAttachmentHidden PidTagLastVerbExecuted PidTagRecipientOrder PidTagBusiness2TelephoneNumbers PidTagSearchFolderRecreateInfo PidTagContainerContents PidTagStreetAddress PidTagExceptionStartTime PidTagRecipientProposed PidTagCodePageId PidTagAutoForwardComment PidTagOriginalSubject PidTagMemberName PidTagReceivedRepresentingName PidTagRecipientTrackStatusTime PidTagMimeSkeleton PidTagRecipientResourceState PidTagAddressBookParentEntryId PidTagSpouseName PidTagMessageRecipientMe PidTagRuleProviderData PidTagAddressBookManager PidTagDeferredSendTime PidTagTargetEntryId PidTagAlternateRecipientAllowed PidTagHobbies PidTagExtendedRuleMessageActions PidTagSubfolders PidTagProfession PidTagWlinkAddressBookEID PidTagRecipientType PidTagMessageClass PidTagFlagStatus PidTagRecordKey PidTagReplyRecipientNames PidTagMessageCcMe PidTagOfflineAddressBookMessageClass PidTagAttachContentId PidTagTelexNumber PidTagSenderName PidTagViewDescriptorVersion PidTagMessageSize PidTagInternetArticleNumber PidTagBlockStatus PidTagVoiceMessageAttachmentOrder PidTagReportTag PidTagAutoResponseSuppress PidTagStateOrProvince PidTagHomeAddressPostOfficeBox PidTagChangeNumber PidTagMemberId PidTagReportTime PidTagCreatorEntryId PidTagOfflineAddressBookContainerGuid PidTagReadReceiptEmailAddress PidTagFreeBusyPublishStart PidTagCallbackTelephoneNumber PidTagSearchFolderId PidTagReportDispositionMode PidTagExceptionReplaceTime PidTagCustomerId PidTagResponsibility PidTagReplyTime PidTagAddressBookSeniorityIndex PidTagScheduleInfoFreeBusy PidTagLocation PidTagPolicyTag PidTagRecipientProposedEndTime PidTagInstanceKey PidTagSecurityDescriptorAsXml PidTagRecipientReassignmentProhibited PidTagBusiness2TelephoneNumber PidTagAddressBookPhoneticDisplayName PidTagAddressBookPublicDelegates PidTagRenderingPosition PidTagChangeKey PidTagIpmAppointmentEntryId PidTagAddressBookTargetAddress PidTagWlinkAddressBookStoreEID PidTagRuleMessageProvider PidTagIpmJournalEntryId PidTagOtherAddressStateOrProvince PidTagRuleName PidTagToDoItemFlags PidTagWlinkCalendarColor PidTagContainerClass PidTagSubjectPrefix PidTagMailboxOwnerEntryId PidTagCurrentDraftEntryId PidTagWeddingAnniversary PidTagAttachDataBinary PidTagAttachNumber PidTagRuleMessageLevel PidTagDisplayType PidTagOriginalMessageId PidTagRecipientProposedStartTime PidTagPurportedSenderDomain PidTagClientActions PidTagHomeAddressCity PidTagCompanyName PidTagTextAttachmentCharset PidTagTemplateData PidTagAddressBookPhoneticSurname PidTagRoamingXmlStream PidTagProhibitReceiveQuota PidTagAddressBookExtensionAttribute7 PidTagDeferredActionMessageOriginalEntryId PidTagExtendedFolderFlags PidTagFaxNumberOfPages PidTagAddressBookEntryId PidTagFreeBusyMessageEmailAddress PidTagAttributeHidden PidTagCarTelephoneNumber PidTagOriginalSubmitTime PidTagOfflineAddressBookSequence PidTagAddressBookOwner PidTagIpmNoteEntryId PidTagAdditionalRenEntryIdsEx PidTagReportSearchKey PidTagTnefCorrelationKey PidTagDelegateFlags PidTagJunkIncludeContacts PidTagListUnsubscribe PidTagAddressBookSenderHintTranslations PidTagWlinkGroupHeaderID PidTagOfflineAddressBookDistinguishedName PidTagInternetCodepage PidTagAddressBookHomeMessageDatabase PidTagOriginalSentRepresentingAddressType PidTagScheduleInfoDisallowRecurringAppts PidTagRtfCompressed PidTagRuleCondition PidTagImportance PidTagPostalCode PidTagRuleMessageState PidTagMessageStatus PidTagTrustSender PidTagOtherAddressCountry PidTagJunkPhishingEnableLinks PidTagAddressBookHierarchicalShowInDepartments PidTagAssistantTelephoneNumber PidTagOutOfOfficeState PidTagAttachFilename PidTagComment PidTagCreatorName PidTagReceivedByEmailAddress PidTagHierarchyChangeNumber PidTagRuleMessageProviderData PidTagBodyContentLocation PidTagIconIndex PidTagScheduleInfoDontMailDelegates PidTagOscSyncEnabled PidTagCdoRecurrenceid PidTagCompanyMainTelephoneNumber PidTagExceptionEndTime PidTagSubfolder PidTagScheduleInfoDelegateNamesW PidTagOriginalDisplayBcc PidTagHasRules PidTagGivenName PidTagAddressBookExtensionAttribute13 PidTagAddressBookExtensionAttribute8 PidTagICalendarEndTime PidTagSenderEmailAddress PidTagFolderType PidTagScheduleInfoFreeBusyAway PidTagOriginalSentRepresentingName PidTagSearchFolderEfpFlags PidTagOfflineAddressBookTruncatedProperties PidTagChildrensNames PidTagReadReceiptName PidTagWlinkOrdinal PidTagProhibitSendQuota PidTagDisplayName PidTagSelectable PidTagSearchFolderDefinition PidTagExpiryNumber PidTagWlinkSection PidTagDepartmentName PidTagOtherAddressPostOfficeBox PidTagRtfInSync PidTagDamBackPatched PidTagOwnerAppointmentId PidTagAddressBookExtensionAttribute6 PidTagAttachLongPathname PidTagICalendarStartTime PidTagRuleActionNumber PidTagInstanceNum PidTagMessageFlags PidTagInternetReferences PidTagAttachAdditionalInformation PidTagParentSourceKey PidTagAttachmentLinkId PidTagAttachDataObject PidTagOfflineAddressBookName PidTagEntryId PidTagAddressBookModerationEnabled);

1;
